@@ -16,7 +16,7 @@ use std::io;
 use semver::{BuildMetadata, Prerelease, Version};
 use serde::Deserialize;
 use toml_edit::{value, Document};
-use vfs::{VfsPath, VfsResult};
+use vfs::VfsPath;
 
 pub mod brew;
 pub mod cargo;
@@ -33,11 +33,10 @@ extern crate spectral;
 
 #[cfg(test)] // <-- not needed in integration tests
 #[macro_use]
-extern crate table_test;
+extern crate mockall;
 
 #[cfg(test)] // <-- not needed in integration tests
-#[macro_use]
-extern crate mockall;
+extern crate rstest;
 
 #[cfg(test)]
 use mockall::{automock, predicate::*};
@@ -129,8 +128,15 @@ fn increment(v: &str, i: Increment) -> Result<Version> {
     Ok(v)
 }
 
-pub fn new_cargo_config_path(root: &VfsPath) -> VfsResult<VfsPath> {
-    root.join(CARGO_CONFIG)
+fn new_cargo_config_path(root: &VfsPath) -> Option<VfsPath> {
+    join(root, CARGO_CONFIG)
+}
+
+fn join(p: &VfsPath, other: &str) -> Option<VfsPath> {
+    match p.join(other) {
+        Ok(r) => Some(r),
+        Err(_) => None,
+    }
 }
 
 fn increment_patch(v: &mut Version) {
@@ -175,7 +181,7 @@ impl CrateConfig {
         let mut file = path.open_file()?;
         let mut content = String::new();
         file.read_to_string(&mut content)?;
-        let conf: CrateConfig = toml::from_str(&content).unwrap();
+        let conf: CrateConfig = toml::from_str(&content)?;
         Ok(conf)
     }
 
@@ -228,6 +234,24 @@ pub enum Increment {
 #[cfg(test)]
 mod tests {
     use super::*;
+    use rstest::*;
+    use spectral::prelude::*;
+
+    #[rstest]
+    #[case::patch(Increment::Patch, "0.1.2")]
+    #[case::minor(Increment::Minor, "0.2.0")]
+    #[case::major(Increment::Major, "1.0.0")]
+    #[trace]
+    fn increment_tests(#[case] incr: Increment, #[case] expected: &str) {
+        // Arrange
+        let v = "0.1.1";
+
+        // Act
+        let actual = increment(v, incr).unwrap();
+
+        // Assert
+        assert_that!(actual).is_equal_to(Version::parse(expected).unwrap());
+    }
 
     #[test]
     fn toml_parse_workspace() {
