@@ -13,12 +13,15 @@ use crate::Increment;
 use crate::Publisher;
 use crate::Vcs;
 
-pub struct Releasable<'a> {
+/// Represents virtual path in a filesystem
+/// that keeps real fs path that is root of this
+/// virtual path
+pub struct VPath<'a> {
     real_path: &'a str,
     virtual_path: VfsPath,
 }
 
-impl<'a> Releasable<'a> {
+impl<'a> VPath<'a> {
     pub fn new(real_path: &'a str, virtual_path: VfsPath) -> Self {
         Self {
             virtual_path,
@@ -31,7 +34,7 @@ pub trait Release<'a> {
     /// Releases crate or workspace
     /// * `root` - path to folder where crate's or workspace's Cargo.toml located
     /// * `incr` - Version increment (major, minor or patch)
-    fn release(&self, root: Releasable<'a>, incr: Increment) -> crate::Result<()>;
+    fn release(&self, root: VPath<'a>, incr: Increment) -> crate::Result<()>;
 }
 
 pub struct Workspace<P: Publisher, V: Vcs> {
@@ -51,7 +54,7 @@ impl<P: Publisher, V: Vcs> Workspace<P, V> {
 }
 
 impl<'a, P: Publisher, V: Vcs> Release<'a> for Workspace<P, V> {
-    fn release(&self, root: Releasable<'a>, incr: Increment) -> crate::Result<()> {
+    fn release(&self, root: VPath<'a>, incr: Increment) -> crate::Result<()> {
         let crate_conf = new_cargo_config_path(&root.virtual_path).unwrap();
 
         let mut it = VersionIter::open(&crate_conf)?;
@@ -96,7 +99,7 @@ impl<P: Publisher, V: Vcs> Crate<P, V> {
 }
 
 impl<'a, P: Publisher, V: Vcs> Release<'a> for Crate<P, V> {
-    fn release(&self, root: Releasable<'a>, incr: Increment) -> crate::Result<()> {
+    fn release(&self, root: VPath<'a>, incr: Increment) -> crate::Result<()> {
         let crate_conf = new_cargo_config_path(&root.virtual_path).unwrap();
 
         let conf = CrateConfig::open(&crate_conf)?;
@@ -127,13 +130,13 @@ mod tests {
     use crate::MockVcs;
     use crate::{MockPublisher, CARGO_CONFIG};
     use mockall::predicate::*;
+    use rstest::*;
     use spectral::prelude::*;
     use vfs::MemoryFS;
 
-    #[test]
-    fn release_workspace() {
+    #[rstest]
+    fn release_workspace(root: VfsPath) {
         // Arrange
-        let root: VfsPath = new_file_system();
         let mut mock_pub = MockPublisher::new();
         let mut mock_vcs = MockVcs::new();
 
@@ -168,19 +171,18 @@ mod tests {
             .returning(|_, _| Ok(()));
 
         let w = Workspace::new(0, mock_pub, mock_vcs);
-        let releasable = Releasable::new("/x", root);
+        let path = VPath::new("/x", root);
 
         // Act
-        let r = w.release(releasable, Increment::Minor);
+        let r = w.release(path, Increment::Minor);
 
         // Assert
         assert_that!(r).is_ok();
     }
 
-    #[test]
-    fn release_crate() {
+    #[rstest]
+    fn release_crate(root: VfsPath) {
         // Arrange
-        let root: VfsPath = new_file_system();
         let mut mock_pub = MockPublisher::new();
         let mut mock_vcs = MockVcs::new();
 
@@ -210,16 +212,17 @@ mod tests {
 
         let c = Crate::new(mock_pub, mock_vcs);
 
-        let releasable = Releasable::new("/x", root.join("solp").unwrap());
+        let path = VPath::new("/x", root.join("solp").unwrap());
 
         // Act
-        let r = c.release(releasable, Increment::Minor);
+        let r = c.release(path, Increment::Minor);
 
         // Assert
         assert_that!(r).is_ok();
     }
 
-    fn new_file_system() -> VfsPath {
+    #[fixture]
+    fn root() -> VfsPath {
         let root = VfsPath::new(MemoryFS::new());
 
         root.join("solv").unwrap().create_dir().unwrap();
